@@ -37,7 +37,7 @@ class RpcServer : public QTcpServer
     Q_OBJECT
 
 public:
-    RpcServer();    //! \todo (LOW) use 'parent' param
+    RpcServer(bool perConnLogs);    //! \todo (LOW) use 'parent' param
     virtual ~RpcServer();
 
     bool registerService(::google::protobuf::Service *service,
@@ -47,7 +47,7 @@ signals:
     void notifyClients(int notifType, SharedProtobufMessage notifData);
 
 protected:
-    void incomingConnection(int socketDescriptor);
+    void incomingConnection(qintptr socketDescriptor);
 
 private:
     ::google::protobuf::Service *service;
