@@ -17,19 +17,18 @@ You should have received a copy of the GNU General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>
 */
 
-#define __STDC_FORMAT_MACROS
-
 #include "abstractport.h"
 
 #include "../common/abstractprotocol.h"
+#include "../common/framevalueattrib.h"
 #include "../common/streambase.h"
 #include "devicemanager.h"
+#include "interfaceinfo.h"
 #include "packetbuffer.h"
 
 #include <QString>
 #include <QIODevice>
 
-#include <inttypes.h>
 #include <limits.h>
 #include <math.h>
 
@@ -50,6 +49,7 @@ AbstractPort::AbstractPort(int id, const char *device)
     minPacketSetSize_ = 1;
 
     deviceManager_ = new DeviceManager(this);
+    interfaceInfo_ = NULL;
 
     maxStatsValue_ = ULLONG_MAX; // assume 64-bit stats
     memset((void*) &stats_, 0, sizeof(stats_));
@@ -59,10 +59,13 @@ AbstractPort::AbstractPort(int id, const char *device)
 AbstractPort::~AbstractPort()
 {
     delete deviceManager_;
+    delete interfaceInfo_;
 }    
 
 void AbstractPort::init()
 {
+    if (deviceManager_)
+        deviceManager_->createHostDevices();
 }    
 
 /*! Can we modify Port with these params? Should modify cause port dirty? */
@@ -84,6 +87,8 @@ bool AbstractPort::canModify(const OstProto::Port &port, bool *dirty)
         *dirty = true;
         allow = !isTransmitOn();
     }
+    if (*dirty)
+        isSendQueueDirty_ = true;
 
     return allow;
 }
@@ -199,31 +204,33 @@ bool AbstractPort::setRateAccuracy(Accuracy accuracy)
     return true;
 }
 
-void AbstractPort::updatePacketList()
+int AbstractPort::updatePacketList()
 {
     switch(data_.transmit_mode())
     {
     case OstProto::kSequentialTransmit:
-        updatePacketListSequential();
+        return updatePacketListSequential();
         break;
     case OstProto::kInterleavedTransmit:
-        updatePacketListInterleaved();
+        return updatePacketListInterleaved();
         break;
     default:
         Q_ASSERT(false); // Unreachable!!!
         break;
     }
+    return 0;
 }
 
-void AbstractPort::updatePacketListSequential()
+int AbstractPort::updatePacketListSequential()
 {
+    FrameValueAttrib packetListAttrib;
     long    sec = 0; 
     long    nsec = 0;
 
     qDebug("In %s", __FUNCTION__);
 
     // First sort the streams by ordinalValue
-    qSort(streamList_.begin(), streamList_.end(), StreamBase::StreamLessThan);
+    std::sort(streamList_.begin(), streamList_.end(), StreamBase::StreamLessThan);
 
     clearPacketList();
 
@@ -295,18 +302,18 @@ void AbstractPort::updatePacketListSequential()
                     n, x, y, burstSize);
 
             qDebug("ibg  = %g", ibg);
-            qDebug("ibg1 = %" PRIu64, ibg1);
-            qDebug("nb1  = %" PRIu64, nb1);
-            qDebug("ibg2 = %" PRIu64, ibg2);
-            qDebug("nb2  = %" PRIu64 "\n", nb2);
+            qDebug("ibg1 = %llu", ibg1);
+            qDebug("nb1  = %llu", nb1);
+            qDebug("ibg2 = %llu", ibg2);
+            qDebug("nb2  = %llu\n", nb2);
 
             qDebug("ipg  = %g", ipg);
-            qDebug("ipg1 = %" PRIu64, ipg1);
-            qDebug("npx1 = %" PRIu64, npx1);
-            qDebug("npy1 = %" PRIu64, npy1);
-            qDebug("ipg2 = %" PRIu64, ipg2);
-            qDebug("npx2 = %" PRIu64, npx2);
-            qDebug("npy2 = %" PRIu64 "\n", npy2);
+            qDebug("ipg1 = %llu", ipg1);
+            qDebug("npx1 = %llu", npx1);
+            qDebug("npy1 = %llu", npy1);
+            qDebug("ipg2 = %llu", ipg2);
+            qDebug("npx2 = %llu", npx2);
+            qDebug("npy2 = %llu\n", npy2);
 
             if (n > 1)
                 loopNextPacketSet(x, n, 0, loopDelay);
@@ -318,8 +325,10 @@ void AbstractPort::updatePacketListSequential()
                 
                 if (j == 0 || frameVariableCount > 1)
                 {
+                    FrameValueAttrib attrib;
                     len = streamList_[i]->frameValue(
-                            pktBuf_, sizeof(pktBuf_), j);
+                            pktBuf_, sizeof(pktBuf_), j, &attrib);
+                    packetListAttrib += attrib;
                 }
                 if (len <= 0)
                     continue;
@@ -390,10 +399,15 @@ void AbstractPort::updatePacketListSequential()
 
 _stop_no_more_pkts:
     isSendQueueDirty_ = false;
+
+    qDebug("PacketListAttrib = %x",
+            static_cast<int>(packetListAttrib.errorFlags));
+    return static_cast<int>(packetListAttrib.errorFlags);
 }
 
-void AbstractPort::updatePacketListInterleaved()
+int AbstractPort::updatePacketListInterleaved()
 {
+    FrameValueAttrib packetListAttrib;
     int numStreams = 0;
     quint64 minGap = ULLONG_MAX;
     quint64 duration = quint64(1e9);
@@ -407,18 +421,26 @@ void AbstractPort::updatePacketListInterleaved()
     QList<bool> isVariable;
     QList<QByteArray> pktBuf;
     QList<ulong> pktLen;
+    int activeStreamCount = 0;
 
     qDebug("In %s", __FUNCTION__);
 
     clearPacketList();
-    if (streamList_.size() == 0)
+
+    for (int i = 0; i < streamList_.size(); i++)
+    {
+        if (streamList_[i]->isEnabled())
+            activeStreamCount++;
+    }
+
+    if (activeStreamCount == 0)
     {
         isSendQueueDirty_ = false;
-        return;
+        return 0;
     }
 
     // First sort the streams by ordinalValue
-    qSort(streamList_.begin(), streamList_.end(), StreamBase::StreamLessThan);
+    std::sort(streamList_.begin(), streamList_.end(), StreamBase::StreamLessThan);
 
     for (int i = 0; i < streamList_.size(); i++)
     {
@@ -470,16 +492,16 @@ void AbstractPort::updatePacketListInterleaved()
         qDebug("numBursts = %g, numPackets = %g\n", numBursts, numPackets);
 
         qDebug("ibg  = %g", ibg);
-        qDebug("ibg1 = %" PRIu64, _ibg1);
-        qDebug("nb1  = %" PRIu64, _nb1);
-        qDebug("ibg2 = %" PRIu64, _ibg2);
-        qDebug("nb2  = %" PRIu64 "\n", _nb2);
+        qDebug("ibg1 = %llu", _ibg1);
+        qDebug("nb1  = %llu", _nb1);
+        qDebug("ibg2 = %llu", _ibg2);
+        qDebug("nb2  = %llu\n", _nb2);
 
         qDebug("ipg  = %g", ipg);
-        qDebug("ipg1 = %" PRIu64, _ipg1);
-        qDebug("np1  = %" PRIu64, _np1);
-        qDebug("ipg2 = %" PRIu64, _ipg2);
-        qDebug("np2  = %" PRIu64 "\n", _np2);
+        qDebug("ipg1 = %llu", _ipg1);
+        qDebug("np1  = %llu", _np1);
+        qDebug("ipg2 = %llu", _ipg2);
+        qDebug("np2  = %llu\n", _np2);
 
 
         if (_ibg2 && (_ibg2 < minGap))
@@ -530,18 +552,21 @@ void AbstractPort::updatePacketListInterleaved()
         }
         else
         {
+            FrameValueAttrib attrib;
             isVariable.append(false);
             pktBuf.append(QByteArray());
             pktBuf.last().resize(kMaxPktSize);
             pktLen.append(streamList_[i]->frameValue(
-                    (uchar*)pktBuf.last().data(), pktBuf.last().size(), 0));
+                    (uchar*)pktBuf.last().data(), pktBuf.last().size(),
+                    0, &attrib));
+            packetListAttrib += attrib;
         }
 
         numStreams++;
     } // for i
 
-    qDebug("minGap   = %" PRIu64, minGap);
-    qDebug("duration = %" PRIu64, duration);
+    qDebug("minGap   = %llu", minGap);
+    qDebug("duration = %llu", duration);
 
     uchar* buf;
     int len;
@@ -563,9 +588,11 @@ void AbstractPort::updatePacketListInterleaved()
             {
                 if (isVariable.at(i))
                 {
+                    FrameValueAttrib attrib;
                     buf = pktBuf_;
                     len = streamList_[i]->frameValue(pktBuf_, sizeof(pktBuf_), 
-                            pktCount[i]);
+                            pktCount[i], &attrib);
+                    packetListAttrib += attrib;
                 }
                 else
                 {
@@ -576,7 +603,7 @@ void AbstractPort::updatePacketListInterleaved()
                 if (len <= 0)
                     continue;
 
-                qDebug("q(%d) sec = %" PRIu64 " nsec = %" PRIu64, i, sec, nsec);
+                qDebug("q(%d) sec = %llu nsec = %llu", i, sec, nsec);
                 appendToPacketList(sec, nsec, buf, len); 
                 lastPktTxSec = sec;
                 lastPktTxNsec = nsec;
@@ -616,9 +643,13 @@ void AbstractPort::updatePacketListInterleaved()
         delayNsec += long(1e9);
         delaySec--;
     }
-    qDebug("loop Delay = %" PRId64 "/%" PRId64, delaySec, delayNsec);
+    qDebug("loop Delay = %lld/%lld", delaySec, delayNsec);
     setPacketListLoopMode(true, delaySec, delayNsec); 
     isSendQueueDirty_ = false;
+
+    qDebug("PacketListAttrib = %x",
+            static_cast<int>(packetListAttrib.errorFlags));
+    return static_cast<int>(packetListAttrib.errorFlags);
 }
 
 void AbstractPort::stats(PortStats *stats)
@@ -781,3 +812,8 @@ quint64 AbstractPort::neighborMacAddress(int streamId, int frameIndex)
 
     return 0;
 }
+
+const InterfaceInfo* AbstractPort::interfaceInfo() const
+{
+    return interfaceInfo_;
+}
