@@ -31,6 +31,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>
 #include "../common/abstractprotocol.h"
 #endif
 
+#include "../common/framevalueattrib.h"
 #include "../common/streambase.h"
 #include "../rpc/pbrpccontroller.h"
 #include "device.h"
@@ -109,6 +110,7 @@ void MyService::getPortConfig(::google::protobuf::RpcController* /*controller*/,
             portInfo[id]->protoDataCopyInto(p);
             portLock[id]->unlock();
         }
+        // XXX: no way to inform RPC caller of an invalid port!
     }
 
     done->Run();
@@ -116,9 +118,12 @@ void MyService::getPortConfig(::google::protobuf::RpcController* /*controller*/,
 
 void MyService::modifyPort(::google::protobuf::RpcController* /*controller*/,
     const ::OstProto::PortConfigList* request,
-    ::OstProto::Ack* /*response*/,
+    ::OstProto::Ack *response,
     ::google::protobuf::Closure* done)
 {
+    bool error = false;
+    QString notes;
+
     // notification needs to be on heap because signal/slot is across threads!
     OstProto::Notification *notif = new OstProto::Notification;
 
@@ -137,21 +142,29 @@ void MyService::modifyPort(::google::protobuf::RpcController* /*controller*/,
 
             if (!portInfo[id]->canModify(port, &dirty)) {
                 qDebug("Port %d cannot be modified - stop tx and retry", id);
-                continue;        //! \todo(LOW): Partial status of RPC
+                error = true;
+                notes += QString("Port %1 modify: operation disallowed on "
+                                 "transmitting port\n").arg(id);
+                continue;
             }
 
             portLock[id]->lockForWrite();
             portInfo[id]->modify(port);
-            if (dirty)
-                portInfo[id]->updatePacketList();
             portLock[id]->unlock();
-
-
             notif->mutable_port_id_list()->add_port_id()->set_id(id);
         }
+        else {
+            error = true;
+            notes += QString("Port %1 modify: invalid port\n").arg(id);
+        }
     }
 
-    //! \todo (LOW): fill-in response "Ack"????
+    if (error) {
+        response->set_status(OstProto::Ack::kRpcError);
+        response->set_notes(notes.toStdString());
+    }
+    else
+        response->set_status(OstProto::Ack::kRpcSuccess);
     done->Run();
 
     if (notif->port_id_list().port_id_size()) {
@@ -190,7 +203,8 @@ void MyService::getStreamIdList(::google::protobuf::RpcController* controller,
     return;
 
 _invalid_port:
-    controller->SetFailed("Invalid Port Id");
+    controller->SetFailed(QString("Port %1 get stream id list: invalid port")
+                            .arg(portId).toStdString());
     done->Run();
 }
 
@@ -216,7 +230,7 @@ void MyService::getStreamConfig(::google::protobuf::RpcController* controller,
 
         stream = portInfo[portId]->stream(request->stream_id(i).id());
         if (!stream)
-            continue;        //! \todo(LOW): Partial status of RPC
+            continue;        //! XXX: no way to inform RPC caller of invalid stream id
 
         s = response->add_stream();
         stream->protoDataCopyInto(*s);
@@ -227,15 +241,18 @@ void MyService::getStreamConfig(::google::protobuf::RpcController* controller,
     return;
 
 _invalid_port:
-    controller->SetFailed("invalid portid");
+    controller->SetFailed(QString("Port %1 get stream config: invalid port")
+                            .arg(portId).toStdString());
     done->Run();
 }
 
 void MyService::addStream(::google::protobuf::RpcController* controller,
     const ::OstProto::StreamIdList* request,
-    ::OstProto::Ack* /*response*/,
+    ::OstProto::Ack* response,
     ::google::protobuf::Closure* done)
 {
+    bool error = false;
+    QString notes;
     int portId;
 
     qDebug("In %s", __PRETTY_FUNCTION__);
@@ -254,8 +271,13 @@ void MyService::addStream(::google::protobuf::RpcController* controller,
 
         // If stream with same id as in request exists already ==> error!!
         stream = portInfo[portId]->stream(request->stream_id(i).id());
-        if (stream)
-            continue;        //! \todo (LOW): Partial status of RPC
+        if (stream) {
+            error = true;
+            notes += QString("Port %1 Stream %2 add stream: "
+                             "stream already exists\n")
+                        .arg(portId).arg(request->stream_id(i).id());
+            continue;
+        }
 
         // Append a new "default" stream - actual contents of the new stream is
         // expected in a subsequent "modifyStream" request - set the stream id
@@ -266,26 +288,35 @@ void MyService::addStream(::google::protobuf::RpcController* controller,
     }
     portLock[portId]->unlock();
 
-    //! \todo (LOW): fill-in response "Ack"????
-
+    if (error) {
+        response->set_status(OstProto::Ack::kRpcError);
+        response->set_notes(notes.toStdString());
+    }
+    else
+        response->set_status(OstProto::Ack::kRpcSuccess);
     done->Run();
     return;
 
 _port_busy:
-    controller->SetFailed("Port Busy");
+    controller->SetFailed(QString("Port %1 add stream: operation disallowed on "
+                                  "transmitting port")
+                            .arg(portId).toStdString());
     goto _exit;
 
 _invalid_port:
-    controller->SetFailed("invalid portid");
+    controller->SetFailed(QString("Port %1 add stream: invalid port")
+                            .arg(portId).toStdString());
 _exit:
     done->Run();
 }
 
 void MyService::deleteStream(::google::protobuf::RpcController* controller,
     const ::OstProto::StreamIdList* request,
-    ::OstProto::Ack* /*response*/,
+    ::OstProto::Ack* response,
     ::google::protobuf::Closure* done)
 {
+    bool error = false;
+    QString notes;
     int portId;
 
     qDebug("In %s", __PRETTY_FUNCTION__);
@@ -298,29 +329,43 @@ void MyService::deleteStream(::google::protobuf::RpcController* controller,
         goto _port_busy;
 
     portLock[portId]->lockForWrite();
-    for (int i = 0; i < request->stream_id_size(); i++)
-        portInfo[portId]->deleteStream(request->stream_id(i).id());
+    for (int i = 0; i < request->stream_id_size(); i++) {
+        if (!portInfo[portId]->deleteStream(request->stream_id(i).id())) {
+            error = true;
+            notes += QString("Port %1 Stream %2 stream delete: "
+                             "stream not found\n")
+                        .arg(portId).arg(request->stream_id(i).id());
+        }
+    }
     portLock[portId]->unlock();
 
-    //! \todo (LOW): fill-in response "Ack"????
-
+    if (error) {
+        response->set_status(OstProto::Ack::kRpcError);
+        response->set_notes(notes.toStdString());
+    }
+    else
+        response->set_status(OstProto::Ack::kRpcSuccess);
     done->Run();
     return;
 
 _port_busy:
-    controller->SetFailed("Port Busy");
+    controller->SetFailed(QString("Port %1 delete stream: operation disallowed "                                  "on transmitting port")
+                            .arg(portId).toStdString());
     goto _exit;
 _invalid_port:
-    controller->SetFailed("invalid portid");
+    controller->SetFailed(QString("Port %1 delete stream: invalid port")
+                            .arg(portId).toStdString());
 _exit:
     done->Run();
 }
 
 void MyService::modifyStream(::google::protobuf::RpcController* controller,
     const ::OstProto::StreamConfigList* request,
-    ::OstProto::Ack* /*response*/,
+    ::OstProto::Ack* response,
     ::google::protobuf::Closure* done)
 {
+    bool error = false;
+    QString notes;
     int    portId;
 
     qDebug("In %s", __PRETTY_FUNCTION__);
@@ -335,66 +380,93 @@ void MyService::modifyStream(::google::protobuf::RpcController* controller,
     portLock[portId]->lockForWrite();
     for (int i = 0; i < request->stream_size(); i++)
     {
-        StreamBase    *stream;
-
-        stream = portInfo[portId]->stream(request->stream(i).stream_id().id());
+        quint32 sid = request->stream(i).stream_id().id();
+        StreamBase *stream = portInfo[portId]->stream(sid);
         if (stream)
         {
             stream->protoDataCopyFrom(request->stream(i));
             portInfo[portId]->setDirty();
         }
+        else {
+            error = true;
+            notes += QString("Port %1 Stream %2 modify stream: "
+                             "stream not found\n").arg(portId).arg(sid);
+        }
     }
-
-    if (portInfo[portId]->isDirty())
-        portInfo[portId]->updatePacketList();
     portLock[portId]->unlock();
 
-    //! \todo(LOW): fill-in response "Ack"????
-
+    if (error) {
+        response->set_status(OstProto::Ack::kRpcError);
+        response->set_notes(notes.toStdString());
+    }
+    else
+        response->set_status(OstProto::Ack::kRpcSuccess);
     done->Run();
     return;
 
 _port_busy:
-    controller->SetFailed("Port Busy");
+    controller->SetFailed(QString("Port %1 modify stream: operation disallowed "                                  "on transmitting port")
+                            .arg(portId).toStdString());
     goto _exit;
 _invalid_port:
-    controller->SetFailed("invalid portid");
+    controller->SetFailed(QString("Port %1 modify stream: invalid port")
+                            .arg(portId).toStdString());
 _exit:
     done->Run();
 }
 
 void MyService::startTransmit(::google::protobuf::RpcController* /*controller*/,
     const ::OstProto::PortIdList* request,
-    ::OstProto::Ack* /*response*/,
+    ::OstProto::Ack* response,
     ::google::protobuf::Closure* done)
 {
+    bool error = false;
+    QString notes;
+
     qDebug("In %s", __PRETTY_FUNCTION__);
 
     for (int i = 0; i < request->port_id_size(); i++)
     {
         int portId;
+        int frameError = 0;
 
         portId = request->port_id(i).id();
-        if ((portId < 0) || (portId >= portInfo.size()))
-            continue;     //! \todo (LOW): partial RPC?
+        if ((portId < 0) || (portId >= portInfo.size())) {
+            error = true;
+            notes += QString("Port %1 start transmit: invalid port\n")
+                        .arg(portId);
+            continue;
+        }
 
         portLock[portId]->lockForWrite();
         if (portInfo[portId]->isDirty())
-            portInfo[portId]->updatePacketList();
+            frameError = portInfo[portId]->updatePacketList();
         portInfo[portId]->startTransmit();
         portLock[portId]->unlock();
+        if (frameError) {
+            error = true;
+            notes += frameValueErrorNotes(portId, frameError);
+        }
     }
 
-    //! \todo (LOW): fill-in response "Ack"????
+    if (error) {
+        response->set_status(OstProto::Ack::kRpcError);
+        response->set_notes(notes.toStdString());
+    }
+    else
+        response->set_status(OstProto::Ack::kRpcSuccess);
 
     done->Run();
 }
 
 void MyService::stopTransmit(::google::protobuf::RpcController* /*controller*/,
     const ::OstProto::PortIdList* request,
-    ::OstProto::Ack* /*response*/,
+    ::OstProto::Ack* response,
     ::google::protobuf::Closure* done)
 {
+    bool error = false;
+    QString notes;
+
     qDebug("In %s", __PRETTY_FUNCTION__);
 
     for (int i = 0; i < request->port_id_size(); i++)
@@ -402,24 +474,35 @@ void MyService::stopTransmit(::google::protobuf::RpcController* /*controller*/,
         int portId;
 
         portId = request->port_id(i).id();
-        if ((portId < 0) || (portId >= portInfo.size()))
-            continue;     //! \todo (LOW): partial RPC?
+        if ((portId < 0) || (portId >= portInfo.size())) {
+            error = true;
+            notes += QString("Port %1 stop transmit: invalid port\n")
+                        .arg(portId);
+            continue;
+        }
 
         portLock[portId]->lockForWrite();
         portInfo[portId]->stopTransmit();
         portLock[portId]->unlock();
     }
 
-    //! \todo (LOW): fill-in response "Ack"????
-
+    if (error) {
+        response->set_status(OstProto::Ack::kRpcError);
+        response->set_notes(notes.toStdString());
+    }
+    else
+        response->set_status(OstProto::Ack::kRpcSuccess);
     done->Run();
 }
 
 void MyService::startCapture(::google::protobuf::RpcController* /*controller*/,
     const ::OstProto::PortIdList* request,
-    ::OstProto::Ack* /*response*/,
+    ::OstProto::Ack* response,
     ::google::protobuf::Closure* done)
 {
+    bool error = false;
+    QString notes;
+
     qDebug("In %s", __PRETTY_FUNCTION__);
 
     for (int i = 0; i < request->port_id_size(); i++)
@@ -427,40 +510,59 @@ void MyService::startCapture(::google::protobuf::RpcController* /*controller*/,
         int portId;
 
         portId = request->port_id(i).id();
-        if ((portId < 0) || (portId >= portInfo.size()))
-            continue;     //! \todo (LOW): partial RPC?
+        if ((portId < 0) || (portId >= portInfo.size())) {
+            error = true;
+            notes += QString("Port %1 start capture: invalid port\n")
+                        .arg(portId);
+            continue;
+        }
 
         portLock[portId]->lockForWrite();
         portInfo[portId]->startCapture();
         portLock[portId]->unlock();
     }
 
-    //! \todo (LOW): fill-in response "Ack"????
-
+    if (error) {
+        response->set_status(OstProto::Ack::kRpcError);
+        response->set_notes(notes.toStdString());
+    }
+    else
+        response->set_status(OstProto::Ack::kRpcSuccess);
     done->Run();
 }
 
 void MyService::stopCapture(::google::protobuf::RpcController* /*controller*/,
     const ::OstProto::PortIdList* request,
-    ::OstProto::Ack* /*response*/,
+    ::OstProto::Ack* response,
     ::google::protobuf::Closure* done)
 {
+    bool error = false;
+    QString notes;
+
     qDebug("In %s", __PRETTY_FUNCTION__);
     for (int i=0; i < request->port_id_size(); i++)
     {
         int portId;
 
         portId = request->port_id(i).id();
-        if ((portId < 0) || (portId >= portInfo.size()))
-            continue;     //! \todo (LOW): partial RPC?
+        if ((portId < 0) || (portId >= portInfo.size())) {
+            error = true;
+            notes += QString("Port %1 stop capture: invalid port\n")
+                        .arg(portId);
+            continue;
+        }
 
         portLock[portId]->lockForWrite();
         portInfo[portId]->stopCapture();
         portLock[portId]->unlock();
     }
 
-    //! \todo (LOW): fill-in response "Ack"????
-
+    if (error) {
+        response->set_status(OstProto::Ack::kRpcError);
+        response->set_notes(notes.toStdString());
+    }
+    else
+        response->set_status(OstProto::Ack::kRpcSuccess);
     done->Run();
 }
 
@@ -488,6 +590,8 @@ void MyService::getCaptureBuffer(::google::protobuf::RpcController* controller,
 
 _invalid_port:
     controller->SetFailed("invalid portid");
+    controller->SetFailed(QString("Port %1 get capture buffer: invalid port")
+                            .arg(portId).toStdString());
     done->Run();
 }
 
@@ -507,7 +611,7 @@ void MyService::getStats(::google::protobuf::RpcController* /*controller*/,
 
         portId = request->port_id(i).id();
         if ((portId < 0) || (portId >= portInfo.size()))
-            continue;     //! \todo(LOW): partial rpc?
+            continue; // XXX: no way to inform RPC caller of invalid port
 
         s = response->add_port_stats();
         s->mutable_port_id()->set_id(request->port_id(i).id());
@@ -547,9 +651,12 @@ void MyService::getStats(::google::protobuf::RpcController* /*controller*/,
 
 void MyService::clearStats(::google::protobuf::RpcController* /*controller*/,
     const ::OstProto::PortIdList* request,
-    ::OstProto::Ack* /*response*/,
+    ::OstProto::Ack* response,
     ::google::protobuf::Closure* done)
 {
+    bool error = false;
+    QString notes;
+
     qDebug("In %s", __PRETTY_FUNCTION__);
 
     for (int i = 0; i < request->port_id_size(); i++)
@@ -557,16 +664,24 @@ void MyService::clearStats(::google::protobuf::RpcController* /*controller*/,
         int portId;
 
         portId = request->port_id(i).id();
-        if ((portId < 0) || (portId >= portInfo.size()))
-            continue;     //! \todo (LOW): partial RPC?
+        if ((portId < 0) || (portId >= portInfo.size())) {
+            error = true;
+            notes += QString("Port %1 clear statistics: invalid port\n")
+                        .arg(portId);
+            continue;
+        }
 
         portLock[portId]->lockForWrite();
         portInfo[portId]->resetStats();
         portLock[portId]->unlock();
     }
 
-    //! \todo (LOW): fill-in response "Ack"????
-
+    if (error) {
+        response->set_status(OstProto::Ack::kRpcError);
+        response->set_notes(notes.toStdString());
+    }
+    else
+        response->set_status(OstProto::Ack::kRpcSuccess);
     done->Run();
 }
 
@@ -584,7 +699,7 @@ void MyService::getStreamStats(
 
         portId = request->port_id_list().port_id(i).id();
         if ((portId < 0) || (portId >= portInfo.size()))
-            continue;     //! \todo(LOW): partial rpc?
+            continue; // XXX: no way to inform RPC caller of invalid port
 
         portLock[portId]->lockForRead();
         if (request->stream_guid_size())
@@ -602,9 +717,12 @@ void MyService::getStreamStats(
 void MyService::clearStreamStats(
     ::google::protobuf::RpcController* /*controller*/,
     const ::OstProto::StreamGuidList* request,
-    ::OstProto::Ack* /*response*/,
+    ::OstProto::Ack* response,
     ::google::protobuf::Closure* done)
 {
+    bool error = false;
+    QString notes;
+
     qDebug("In %s", __PRETTY_FUNCTION__);
 
     for (int i = 0; i < request->port_id_list().port_id_size(); i++)
@@ -612,8 +730,12 @@ void MyService::clearStreamStats(
         int portId;
 
         portId = request->port_id_list().port_id(i).id();
-        if ((portId < 0) || (portId >= portInfo.size()))
-            continue;     //! \todo (LOW): partial RPC?
+        if ((portId < 0) || (portId >= portInfo.size())) {
+            error = true;
+            notes += QString("Port %1 clear stream statistics: invalid port\n")
+                        .arg(portId);
+            continue;
+        }
 
         portLock[portId]->lockForWrite();
         if (request->stream_guid_size())
@@ -625,8 +747,12 @@ void MyService::clearStreamStats(
         portLock[portId]->unlock();
     }
 
-    //! \todo (LOW): fill-in response "Ack"????
-
+    if (error) {
+        response->set_status(OstProto::Ack::kRpcError);
+        response->set_notes(notes.toStdString());
+    }
+    else
+        response->set_status(OstProto::Ack::kRpcSuccess);
     done->Run();
 }
 
@@ -675,6 +801,50 @@ _invalid_version:
     done->Run();
 }
 
+void MyService::build(::google::protobuf::RpcController* controller,
+    const ::OstProto::BuildConfig* request,
+    ::OstProto::Ack* response,
+    ::google::protobuf::Closure* done)
+{
+    QString notes;
+    int    portId;
+    int    frameError = 0;
+
+    qDebug("In %s", __PRETTY_FUNCTION__);
+
+    portId = request->port_id().id();
+    if ((portId < 0) || (portId >= portInfo.size()))
+        goto _invalid_port;
+
+    if (portInfo[portId]->isTransmitOn())
+        goto _port_busy;
+
+    portLock[portId]->lockForWrite();
+    if (portInfo[portId]->isDirty())
+        frameError = portInfo[portId]->updatePacketList();
+    portLock[portId]->unlock();
+
+    if (frameError) {
+        notes += frameValueErrorNotes(portId, frameError);
+        response->set_status(OstProto::Ack::kRpcError);
+        response->set_notes(notes.toStdString());
+    }
+    else
+        response->set_status(OstProto::Ack::kRpcSuccess);
+    done->Run();
+    return;
+
+_port_busy:
+    controller->SetFailed(QString("Port %1 build: operation disallowed "                                  "on transmitting port")
+                            .arg(portId).toStdString());
+    goto _exit;
+_invalid_port:
+    controller->SetFailed(QString("Port %1 build: invalid port")
+                            .arg(portId).toStdString());
+_exit:
+    done->Run();
+}
+
 /*
  * ===================================================================
  * Device Emulation
@@ -718,7 +888,8 @@ void MyService::getDeviceGroupIdList(
     return;
 
 _invalid_port:
-    controller->SetFailed("Invalid Port Id");
+    controller->SetFailed(QString("Port %1 get device group id list: "
+                                  "invalid port").arg(portId).toStdString());
     done->Run();
 }
 
@@ -747,7 +918,7 @@ void MyService::getDeviceGroupConfig(
 
         dg = devMgr->deviceGroup(request->device_group_id(i).id());
         if (!dg)
-            continue;        //! \todo(LOW): Partial status of RPC
+            continue; // XXX: no way to inform RPC caller of invalid dgid
 
         response->add_device_group()->CopyFrom(*dg);
     }
@@ -757,16 +928,19 @@ void MyService::getDeviceGroupConfig(
     return;
 
 _invalid_port:
-    controller->SetFailed("invalid portid");
+    controller->SetFailed(QString("Port %1 get device group config: "
+                                  "invalid port").arg(portId).toStdString());
     done->Run();
 }
 
 void MyService::addDeviceGroup(
     ::google::protobuf::RpcController* controller,
     const ::OstProto::DeviceGroupIdList* request,
-    ::OstProto::Ack* /*response*/,
+    ::OstProto::Ack* response,
     ::google::protobuf::Closure* done)
 {
+    bool error = false;
+    QString notes;
     DeviceManager *devMgr;
     int portId;
 
@@ -788,24 +962,37 @@ void MyService::addDeviceGroup(
         const OstProto::DeviceGroup *dg = devMgr->deviceGroup(id);
 
         // If device group with same id as in request exists already ==> error!
-        if (dg)
-            continue;        //! \todo (LOW): Partial status of RPC
+        if (dg) {
+            error = true;
+            notes += QString("Port %1 DeviceGroup %2 add device group: "
+                             " device group already exists\n")
+                        .arg(portId).arg(id);
+            continue;
+        }
 
         devMgr->addDeviceGroup(id);
     }
     portLock[portId]->unlock();
 
-    //! \todo (LOW): fill-in response "Ack"????
-
+    if (error) {
+        response->set_status(OstProto::Ack::kRpcError);
+        response->set_notes(notes.toStdString());
+    }
+    else
+        response->set_status(OstProto::Ack::kRpcSuccess);
     done->Run();
     return;
 
 _port_busy:
-    controller->SetFailed("Port Busy");
+    controller->SetFailed(QString("Port %1 add device group: "
+                                  "operation disallowed on transmitting port")
+                            .arg(portId).toStdString());
     goto _exit;
 
 _invalid_port:
-    controller->SetFailed("invalid portid");
+    controller->SetFailed(QString("Port %1 add device group: "
+                                  "invalid port")
+                            .arg(portId).toStdString());
 _exit:
     done->Run();
 }
@@ -813,9 +1000,11 @@ _exit:
 void MyService::deleteDeviceGroup(
     ::google::protobuf::RpcController* controller,
     const ::OstProto::DeviceGroupIdList* request,
-    ::OstProto::Ack* /*response*/,
+    ::OstProto::Ack* response,
     ::google::protobuf::Closure* done)
 {
+    bool error = false;
+    QString notes;
     DeviceManager *devMgr;
     int portId;
 
@@ -831,20 +1020,33 @@ void MyService::deleteDeviceGroup(
         goto _port_busy;
 
     portLock[portId]->lockForWrite();
-    for (int i = 0; i < request->device_group_id_size(); i++)
-        devMgr->deleteDeviceGroup(request->device_group_id(i).id());
+    for (int i = 0; i < request->device_group_id_size(); i++) {
+        quint32 id = request->device_group_id(i).id();
+        if (!devMgr->deleteDeviceGroup(id)) {
+            error = true;
+            notes += QString("Port %1 DeviceGroup %2 delete device group: "
+                             "device group not found\n").arg(portId).arg(id);
+        }
+    }
     portLock[portId]->unlock();
 
-    //! \todo (LOW): fill-in response "Ack"????
-
+    if (error) {
+        response->set_status(OstProto::Ack::kRpcError);
+        response->set_notes(notes.toStdString());
+    }
+    else
+        response->set_status(OstProto::Ack::kRpcSuccess);
     done->Run();
     return;
 
 _port_busy:
-    controller->SetFailed("Port Busy");
+    controller->SetFailed(QString("Port %1 delete device group: "
+                                  "operation disallowed on transmitting port")
+                            .arg(portId).toStdString());
     goto _exit;
 _invalid_port:
-    controller->SetFailed("invalid portid");
+    controller->SetFailed(QString("Port %1 delete device group: "
+                                  "invalid port").arg(portId).toStdString());
 _exit:
     done->Run();
 }
@@ -852,9 +1054,11 @@ _exit:
 void MyService::modifyDeviceGroup(
     ::google::protobuf::RpcController* controller,
     const ::OstProto::DeviceGroupConfigList* request,
-    ::OstProto::Ack* /*response*/,
+    ::OstProto::Ack* response,
     ::google::protobuf::Closure* done)
 {
+    bool error = false;
+    QString notes;
     DeviceManager *devMgr;
     int portId;
 
@@ -870,20 +1074,33 @@ void MyService::modifyDeviceGroup(
         goto _port_busy;
 
     portLock[portId]->lockForWrite();
-    for (int i = 0; i < request->device_group_size(); i++)
-        devMgr->modifyDeviceGroup(&request->device_group(i));
+    for (int i = 0; i < request->device_group_size(); i++) {
+        quint32 id = request->device_group(i).device_group_id().id();
+        if (!devMgr->modifyDeviceGroup(&request->device_group(i))) {
+            error = true;
+            notes += QString("Port %1 DeviceGroup %2 modify device group: "
+                             "device group not found\n").arg(portId).arg(id);
+        }
+    }
     portLock[portId]->unlock();
 
-    //! \todo(LOW): fill-in response "Ack"????
-
+    if (error) {
+        response->set_status(OstProto::Ack::kRpcError);
+        response->set_notes(notes.toStdString());
+    }
+    else
+        response->set_status(OstProto::Ack::kRpcSuccess);
     done->Run();
     return;
 
 _port_busy:
-    controller->SetFailed("Port Busy");
+    controller->SetFailed(QString("Port %1 modify device group: "
+                                  "operation disallowed on transmitting port")
+                            .arg(portId).toStdString());
     goto _exit;
 _invalid_port:
-    controller->SetFailed("invalid portid");
+    controller->SetFailed(QString("Port %1 modify device group: "
+                                  "invalid port").arg(portId).toStdString());
 _exit:
     done->Run();
 }
@@ -914,16 +1131,20 @@ void MyService::getDeviceList(
     return;
 
 _invalid_port:
-    controller->SetFailed("Invalid Port Id");
+    controller->SetFailed(QString("Port %1 get device list: "
+                                  "invalid port").arg(portId).toStdString());
     done->Run();
 }
 
 void MyService::resolveDeviceNeighbors(
     ::google::protobuf::RpcController* /*controller*/,
     const ::OstProto::PortIdList* request,
-    ::OstProto::Ack* /*response*/,
+    ::OstProto::Ack* response,
     ::google::protobuf::Closure* done)
 {
+    bool error = false;
+    QString notes;
+
     qDebug("In %s", __PRETTY_FUNCTION__);
 
     for (int i = 0; i < request->port_id_size(); i++)
@@ -931,25 +1152,36 @@ void MyService::resolveDeviceNeighbors(
         int portId;
 
         portId = request->port_id(i).id();
-        if ((portId < 0) || (portId >= portInfo.size()))
-            continue;     //! \todo (LOW): partial RPC?
+        if ((portId < 0) || (portId >= portInfo.size())) {
+            error = true;
+            notes += QString("Port %1 resolve device neighbors: "
+                             "invalid port\n").arg(portId);
+            continue;
+        }
 
         portLock[portId]->lockForWrite();
         portInfo[portId]->resolveDeviceNeighbors();
         portLock[portId]->unlock();
     }
 
-    //! \todo (LOW): fill-in response "Ack"????
-
+    if (error) {
+        response->set_status(OstProto::Ack::kRpcError);
+        response->set_notes(notes.toStdString());
+    }
+    else
+        response->set_status(OstProto::Ack::kRpcSuccess);
     done->Run();
 }
 
 void MyService::clearDeviceNeighbors(
     ::google::protobuf::RpcController* /*controller*/,
     const ::OstProto::PortIdList* request,
-    ::OstProto::Ack* /*response*/,
+    ::OstProto::Ack* response,
     ::google::protobuf::Closure* done)
 {
+    bool error = false;
+    QString notes;
+
     qDebug("In %s", __PRETTY_FUNCTION__);
 
     for (int i = 0; i < request->port_id_size(); i++)
@@ -957,16 +1189,24 @@ void MyService::clearDeviceNeighbors(
         int portId;
 
         portId = request->port_id(i).id();
-        if ((portId < 0) || (portId >= portInfo.size()))
-            continue;     //! \todo (LOW): partial RPC?
+        if ((portId < 0) || (portId >= portInfo.size())) {
+            error = true;
+            notes += QString("Port %1 clear device neighbors: "
+                             "invalid port\n").arg(portId);
+            continue;
+        }
 
         portLock[portId]->lockForWrite();
         portInfo[portId]->clearDeviceNeighbors();
         portLock[portId]->unlock();
     }
 
-    //! \todo (LOW): fill-in response "Ack"????
-
+    if (error) {
+        response->set_status(OstProto::Ack::kRpcError);
+        response->set_notes(notes.toStdString());
+    }
+    else
+        response->set_status(OstProto::Ack::kRpcSuccess);
     done->Run();
 }
 
@@ -996,10 +1236,34 @@ void MyService::getDeviceNeighbors(
     return;
 
 _invalid_port:
-    controller->SetFailed("Invalid Port Id");
+    controller->SetFailed(QString("Port %1 get device neighbors: "
+                                  "invalid port").arg(portId).toStdString());
     done->Run();
 }
 
+QString MyService::frameValueErrorNotes(int portId, int error)
+{
+    if (!error)
+        return QString();
+
+    QString pfx = QString("Port %1: ").arg(portId);
+    auto errorFlags = static_cast<FrameValueAttrib::ErrorFlags>(error);
+
+    // If smac resolve fails, dmac will always fail - so check that first
+    // and report only that so as not to confuse users (they may not realize
+    // that without a source device, we have no ARP table to lookup for dmac)
+
+    if (errorFlags & FrameValueAttrib::UnresolvedSrcMacError)
+        return pfx + "Source mac resolve failed for one or more "
+                     "streams - Device matching stream's source IP not found\n";
+
+    if (errorFlags & FrameValueAttrib::UnresolvedDstMacError)
+        return pfx + "Destination mac resolve failed for one or more "
+                     "streams - possible ARP/ND failure\n";
+
+    return QString();
+}
+
 /*
  * ===================================================================
  * Friends
