@@ -207,6 +207,9 @@ PcapPort::PortMonitor::PortMonitor(const char *device, Direction direction,
     char errbuf[PCAP_ERRBUF_SIZE] = "";
     bool noLocalCapture;
 
+    setObjectName(QString("Mon%1:%2")
+                    .arg(direction == kDirectionRx ? "Rx" : "Tx")
+                    .arg(device));
     direction_ = direction;
     isDirectional_ = true;
     isPromisc_ = true;
@@ -342,7 +345,8 @@ void PcapPort::PortMonitor::run()
 void PcapPort::PortMonitor::stop()
 {
     stop_ = true;
-    pcap_breakloop(handle());
+    if (handle())
+        pcap_breakloop(handle());
 }
 
 /*
@@ -353,6 +357,7 @@ void PcapPort::PortMonitor::stop()
 PcapPort::PortCapturer::PortCapturer(const char *device)
 {
     device_ = QString::fromLatin1(device);
+    setObjectName(QString("Capture:%1").arg(device_));
     stop_ = false;
     state_ = kNotStarted;
 
@@ -404,6 +409,11 @@ _retry:
     }
 
     dumpHandle_ = pcap_dump_open(handle_, qPrintable(capFile_.fileName()));
+    if (!dumpHandle_) {
+        qDebug("failed to start capture: %s", pcap_geterr(handle_));
+        goto _exit;
+    }
+
     PcapSession::preRun();
     state_ = kRunning;
     while (1)
@@ -501,6 +511,7 @@ PcapPort::EmulationTransceiver::EmulationTransceiver(const char *device,
         DeviceManager *deviceManager)
 {
     device_ = QString::fromLatin1(device);
+    setObjectName(QString("EmulXcvr:%1").arg(device_));
     deviceManager_ = deviceManager;
     stop_ = false;
     state_ = kNotStarted;
